@@ -1,8 +1,8 @@
 #!/bin/sh -e
-mkfs.vfat -n boot -I /dev/vdb
+mkudffs -m hd -l boot /dev/vdb
 mkdir /tmp/boot
 mount /dev/vdb /tmp/boot
 cp -var /boot/* /tmp/boot || true
 umount /tmp/boot
-echo "LABEL=boot      /boot    vfat   defaults        0 1" >> /etc/fstab
+echo "LABEL=boot      /boot    udf   defaults        0 1" >> /etc/fstab
 mount -a
